function [CO2] = VTmicro(v, a, option)
% Syntax:  [CO, HC, NOx, CO2, Fc] = dcsc_09_049_vtmicro(v, a, option)
%
% Purpose: Computes emissions (CO, HC, NO_x, and CO_2) and fuel consumption
%          (Fc) based on the VT-micro model.
%          option selects the dimension of the output
%          option = 1 ==> CO, HC, NOx, CO2 are in kg/m and Fc is in l/m
%          option = 2 ==> CO, HC, NOx, CO2 are in kg/s and Fc is in l/s
%
% Inputs:  v       m by n matrix with speeds in m/s
%          a       m by n matrix with accelerations in m/s^2
%          option  1 or 2 (optional, default value: 1)
%
% Outputs: CO,HC,NOx,CO2,Fc  m by n matrices

% Created: Dec  3, 2008         by Solomon Zegeye
% Last modified: Jul 31, 2011   by Bart De Schutter

% [nr, nc] = size(v);
% [na, Ta] = size(a);
% nr=1; nc=1;
% na=1; Ta=1;
% if nr~=na || nc~=Ta
%     error('The sizes of the input variables should be equal')
%     
% end
% 
% if nargin==2
%     option=1;
% end

% if nr == 0 || nc  == 0
%     CO2 = [];
%     return;
% end

% the speed and accelaration inputs for the vt-micro are in ft/s and
% ft/s^2. In the following we make unit conversion of the inputs.

% 1 meters = 3.2803985 feet
% 1 American galons = 3.785411784 liters

% if nr<=nc
    vf = v'*3.28084;  % conversion of speed to ft/s
    af = a'*3.28084;  % conversion of acceleration to ft/s^2
    v = v';
% else
%     vf = v*3.28084;  % conversion of speed to ft/s
%     af = a*3.28084;  % conversion of acceleration to ft/s^2
% end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%                    Begin  VT Micro                        %%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%          Fuel         CO         HC          NOx

%  p  =  [-0.67944;   % a
%          0.135273;  % b
%          0.015946;  % c         
%         -0.00119;   % d
%          0.029665;  % e         
%         -0.00028;   % f        
%          1.49e-6;   % g         
%          0.004808;  % h         
%         -2.1e-5;   % i        
%          5.54e-8;   % j         
%          8.33e-5;  % k         
%          9.37e-7;    % l         
%         -2.5e-8;    % m        
%         -6.1e-5;   % n
%          3.04e-7;   % o
%         -4.5e-9];   % p
%   
% %==============================================
% kf  = p(:,1);   % fuel consumption coefficients      

%==============================================
Ec_fc  =  [-0.67944   0.135273   0.015946   -0.00119;
           0.029665   0.004808   8.33e-5  -6.1e-5;
           -0.00028   -2.1e-5   9.37e-7  3.04e-7;
           1.49e-6   5.54e-8  -2.5e-8  -4.5e-9];
%%%%===================================================================%%%%
%%%%     Computation of emissions at every speed and acceleration      %%%%
%%%%===================================================================%%%%

ae = [ones(size(af)); af; af^2; af^3];
ve = [ones(size(vf)) vf vf^2 vf^3];

Fc = NaN(size(v));
    
for i=1:length(v)
    Fc(i)  = exp(ve(i,:)*Ec_fc*ae(:,i));  % gal/h
end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%              END of VT-micro                     %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 

% output dimention conversion (to SI units)
    if option==1
        Fc  = Fc*3.785412./(3600*v);    % l/m
        % CO2 emission computation as per Oliver-Hoyo's equations. The fuel
        % consumption need be in l/100km. The output of the Hoyo model is
        % that the CO2 is given in g/km, hence it also needs conversion to
        % kg/m.
      
      % Next lines corrected by BDS as per Solomon's email of July 31, 2011:
      
      % CO2 = (2.39e5*Fc + 0.035e-6;  %  kg/m for gasoline
        CO2 = 2.65*Fc + 1.17e-6;        %  kg/m for diesel
         
    elseif option==2
        Fc  = Fc*3.785412/3600;     % l/s
        
      % CO2 = (2.39e5*Fc + 0.035e-6*v;  %  kg/s for gasoline
        CO2 = (2.65*Fc + 1.17e-6*v);    %  kg/s for diesel
    else
        error('The option has to be 1 or 2')
    end
end

%%%%===================================================================%%%%
%%%%                     THE END                                       %%%%
%%%%===================================================================%%%%
